@@ -26,13 +26,10 @@ import re
 from datetime import date, datetime, timedelta
 from enum import Enum
 
-from backports.datetime_fromisoformat import MonkeyPatch
 from dateutil.relativedelta import relativedelta
 from toolz import mapcat
 from toolz.curried import get
 
-MonkeyPatch.patch_fromisoformat()
-
 log = logging.getLogger(__name__)
 
 
